@@ -77,7 +77,6 @@ def reddim(data,indices,el = 0):
             SEL[dim] = range(size(data,axis=dim))
     return data[arraysel(SEL,shape(data))]
 
-
 def sizeout(data,axisref,deffunc):
     SEL = list(repeat(None,len(shape(data))))
     sizeout = list(repeat(None,len(shape(data))))
@@ -110,9 +109,15 @@ def sizeout(data,axisref,deffunc):
     #                        lambda data: deffunc(data) )
     # get the output coordinates of the processed dimensions and save it as a seperate list
     if type(dummydataout).__name__ == 'list':
-        outcoords = dummydataout[1] 
+        if type(dummydataout[1]).__name__ != 'list': # multiple coordinate set stored as a list
+            outcoords = list(dummydataout[1])
+        else:
+            outcoords = dummydataout[1] 
     else:
-        outcoords = None
+        outcoords = None # function doesn't have output coordinates available
+
+    # sizeout: size of the output data if one would apply multifunc
+    # outcoords: list of coordinate sets of each dimension where axisref == True
     return sizeout, outcoords
 
 
