@@ -60,6 +60,15 @@ def avgcycle(data, timeco = None, timewarp = None, cclose=False):
         dataout.append(dataout[0])
     return(list([array(dataout),array(timecoout)]))    
     
+# calculate deviation from mean
+def anomaly(x):
+    y = zeros(len(x))
+    meanx = mean(x)
+    for ix,ex in enumerate(x):
+        y[ix] = ex -meanx
+    return (y)
+
+
 
 
 # select data
